import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

//loading the Iris dataset
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', 
  'a08a1080b88344b0c8a7/', 
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', 
  'iris.csv', 
].join('');

//parsing the Iris dataset
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//defining the values of x and y axes, defining the title of the legend
const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';

//d3.async() function returns a value
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'setosa':
              return 'steelblue';
            case 'versicolor':
              return 'fuchsia';
            default:
              return 'orange';
          }
        }

  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
 
//defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(4);
  
//using svg elements 'transform' and 'translate' to define the scatter plot and legend 
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);

//defining the shape and structure of data points using svg elements
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];

  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /*Generates 'petal_width', 'sepal_width', 'petal_length', 'sepal_length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("stroke","black")
          .text(colorLabel);

//defining the title of the scatter plot
svg.append("text").attr("x", 450).attr("y", 20).text("Scatter Plot for Iris Dataset").style("font-size", "25px").attr("alignment-baseline","middle").attr("text-anchor","middle")

//labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Virginica").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.text("Sepal Length");
    
//including points for legend
    svg.append("rect").attr("x",130).attr("y",60).attr("width", 15).attr("height", 15).style("fill", "steelblue")
		svg.append("rect").attr("x",130).attr("y",90).attr("width", 15).attr("height", 15).style("fill", "fuchsia")
		svg.append("rect").attr("x",130).attr("y",120).attr("width", 15).attr("height", 15).style("fill", "orange")
    
//plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
      		.text("Petal Width");

    //plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
      		.text("Sepal Width");
//plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
      		.text("Petal Length");
//plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
      		.text("Sepal Length");
    i++;
  }, 2000);// for every 2 seconds, change the visualization
};
main();



